@@ -1,7 +1,7 @@
 import math
 import time
 from bitarray import bitarray
-from pyrpio.i2c import I2C
+from pyrpio.i2c import I2CBase
 from pyrpio.i2c_register_device import I2CRegisterDevice
 from .defs import LMK61E2ClockMode, LMK61E2Registers
 from .utils import float2frac
@@ -9,7 +9,14 @@ from .utils import float2frac
 
 class LMK61E2:
 
-    def __init__(self, bus: I2C, address: int):
+    def __init__(self, bus: I2CBase, address: int):
+        """ The LMK61E2 device is an ultra-low jitter PLLatinumTM programmable oscillator with a fractional-N
+        frequency synthesizer with integrated VCO that generates commonly used reference clocks.
+
+        Args:
+            bus (I2CBase): I2C bus interface
+            address (int): I2C address of chip
+        """
         self.address = address
         self.i2c_reg = I2CRegisterDevice(bus, address, register_size=1, data_size=1)
 
@@ -48,7 +55,14 @@ class LMK61E2:
         return regs
 
     def regs2freq(self, regs: LMK61E2Registers) -> float:
-        ''' Compute frequency (Hz) from registers. '''
+        """Compute frequency (Hz) from registers.
+
+        Args:
+            regs (LMK61E2Registers): LMK61E2 register set
+
+        Returns:
+            float: Frequency in Hz
+        """
         # Compute target frequency
         f_ref = 50.0*1E6
         frac_float = 0
@@ -59,7 +73,18 @@ class LMK61E2:
         return freq_hz
 
     def freq2regs(self, freq_hz, odf: LMK61E2ClockMode = LMK61E2ClockMode.LVDS) -> LMK61E2Registers:
-        ''' Compute registers from frequency (Hz). ODF is clock mode (2 = LVDS). '''
+        """Compute registers from frequency (Hz). ODF is clock mode (2 = LVDS).
+
+        Args:
+            freq_hz (float): Target frequency in Hz
+            odf (LMK61E2ClockMode, optional):  clock mode (2 = LVDS). Defaults to LMK61E2ClockMode.LVDS.
+
+        Raises:
+            Exception: If frequency is not achievable
+
+        Returns:
+            LMK61E2Registers: LMK61E2 registers
+        """
         regs = LMK61E2Registers()
         f_out = freq_hz  # *1.0E6
         # Fixed values (Enable doubler by default)
@@ -101,8 +126,13 @@ class LMK61E2:
             regs.c3 = 1  # 3rd order filter enabled
         return regs
 
-    def set_registers(self, regs: LMK61E2Registers, nonvolatile=False):
-        ''' Writes registers to clock IC '''
+    def set_registers(self, regs: LMK61E2Registers, nonvolatile: bool = False):
+        """Writes registers to clock IC.
+
+        Args:
+            regs (LMK61E2Registers): LMK61E2 register set
+            nonvolatile (bool, optional): Write to non-volatile memory. Defaults to False.
+        """
         # Binarize data
         reg_data = bitarray(
             format(regs.out_div, '016b') +  # (7-bit 0 w/  9-bit OUTDIV)
