@@ -1,8 +1,17 @@
 import math
+from typing import Tuple
 
 
-def float2frac(x, error=1e-9):
-    ''' float to fraction (numerator / denominator). '''
+def float2frac(x: float, error: float = 1e-9) -> Tuple[int, int]:
+    """Convert floating point to closest fraction
+
+    Args:
+        x (float): Floating-point number
+        error (float, optional): Error bound. Defaults to 1e-9.
+
+    Returns:
+        Tuple[int, int]: Numerator, Denominator
+    """
     n = int(math.floor(x))
     x -= n
     if x < error:
